pub struct IterationStats {
pub iteration: usize,
pub cost: f64,
pub cost_change: f64,
pub gradient_norm: f64,
pub step_norm: f64,
pub tr_ratio: f64,
pub tr_radius: f64,
pub ls_iter: usize,
pub iter_time_ms: f64,
pub total_time_ms: f64,
pub accepted: bool,
}Expand description
Per-iteration statistics for detailed logging (Ceres-style output).
Captures all relevant metrics for each optimization iteration, enabling detailed analysis and debugging of the optimization process.
Fields
iteration: usizeIteration number (0-indexed)
cost: f64Cost function value at this iteration
cost_change: f64Change in cost from previous iteration
gradient_norm: f64L2 norm of the gradient (||J^T·r||)
step_norm: f64L2 norm of the parameter update step (||Δx||)
tr_ratio: f64Trust region ratio (ρ = actual_reduction / predicted_reduction)
tr_radius: f64Trust region radius (damping parameter λ for LM, Δ for Dog Leg)
ls_iter: usizeLinear solver iterations (0 for direct solvers like Cholesky)
iter_time_ms: f64Time taken for this iteration in milliseconds
total_time_ms: f64Total elapsed time since optimization started in milliseconds
accepted: boolWhether the step was accepted (true) or rejected (false)
Implementations
Sourceimpl IterationStats
impl IterationStats
Sourcepub fn print_header()
pub fn print_header()
Print table header in Ceres-style format
Sourcepub fn print_line(&self)
pub fn print_line(&self)
Print single iteration line in Ceres-style format with scientific notation