SE3

Struct SE3 

pub struct SE3 { /* private fields */ }
SE(3) group element representing rigid body transformations in 3D.

Stored as a flat SVector<f64, 7> = [tx, ty, tz, qw, qx, qy, qz] for contiguous memory compatible with zero-copy faer views.

Implementations

Source

impl SE3

pub const DIM: usize = 3

Space dimension - dimension of the ambient space that the group acts on

pub const DOF: usize = 6

Degrees of freedom - dimension of the tangent space

pub const REP_SIZE: usize = 7

Representation size - size of the underlying data representation

pub fn identity() -> SE3

Get the identity element of the group.

Returns the neutral element e such that e ∘ g = g ∘ e = g for any group element g.

pub fn jacobian_identity() -> Matrix<f64, Const<6>, Const<6>, ArrayStorage<f64, 6, 6>>

Get the identity matrix for Jacobians.

Returns the identity matrix in the appropriate dimension for Jacobian computations.

pub fn new( translation: Matrix<f64, Const<3>, Const<1>, ArrayStorage<f64, 3, 1>>, rotation: Unit<Quaternion<f64>>, ) -> SE3

Create a new SE3 element from translation and rotation.

Arguments
  • translation - Translation vector [x, y, z]
  • rotation - Unit quaternion representing rotation
pub fn from_translation_quaternion( translation: Matrix<f64, Const<3>, Const<1>, ArrayStorage<f64, 3, 1>>, quaternion: Quaternion<f64>, ) -> SE3

Create SE3 from translation and raw quaternion (will be normalized).

pub fn from_translation_euler( x: f64, y: f64, z: f64, roll: f64, pitch: f64, yaw: f64, ) -> SE3

Create SE3 from translation components and Euler angles.

pub fn from_isometry(isometry: Isometry<f64, Unit<Quaternion<f64>>, 3>) -> SE3

Create SE3 directly from an Isometry3.

pub fn from_translation_so3( translation: Matrix<f64, Const<3>, Const<1>, ArrayStorage<f64, 3, 1>>, rotation: SO3, ) -> SE3

Create SE3 from SO3 and Vector3 components.

pub fn translation( &self, ) -> Matrix<f64, Const<3>, Const<1>, ArrayStorage<f64, 3, 1>>

Get the translation part as a Vector3.

pub fn rotation_so3(&self) -> SO3

Get the rotation part as SO3.

pub fn rotation_quaternion(&self) -> Unit<Quaternion<f64>>

Get the rotation part as a UnitQuaternion.

pub fn isometry(&self) -> Isometry<f64, Unit<Quaternion<f64>>, 3>

Get as an Isometry3 (convenience method).

pub fn matrix(&self) -> Matrix<f64, Const<4>, Const<4>, ArrayStorage<f64, 4, 4>>

Get the transformation matrix (4x4 homogeneous matrix).

pub fn x(&self) -> f64

Get the x component of translation.

pub fn y(&self) -> f64

Get the y component of translation.

pub fn z(&self) -> f64

Get the z component of translation.

pub fn coeffs(&self) -> [f64; 7]

Get coefficients as array [tx, ty, tz, qw, qx, qy, qz].