pub struct Problem { /* private fields */ }Implementations
Sourceimpl Problem
impl Problem
pub fn new(jacobian_mode: JacobianMode) -> Self
Sourcepub fn mark_as_schur_landmark(&mut self, key: VarKey)
pub fn mark_as_schur_landmark(&mut self, key: VarKey)
Mark a variable as a Schur complement landmark (eliminated block).
Call this for every landmark/point variable when using a Schur complement solver. Variables not marked here are treated as camera-block variables.
Sourcepub fn add_variable(
&mut self,
manifold_type: ManifoldType,
params: DVector<f64>,
) -> VarKey
pub fn add_variable( &mut self, manifold_type: ManifoldType, params: DVector<f64>, ) -> VarKey
Add a variable with a given manifold type and initial parameter vector.
Returns a stable VarKey handle for use in add_residual_block, fix_variable, etc.
Sourcepub fn add_residual_block(
&mut self,
variable_keys: &[VarKey],
factor: Box<dyn Factor + Send>,
loss_func: Option<Box<dyn LossFunction + Send>>,
) -> FactorKey
pub fn add_residual_block( &mut self, variable_keys: &[VarKey], factor: Box<dyn Factor + Send>, loss_func: Option<Box<dyn LossFunction + Send>>, ) -> FactorKey
Add a residual block (factor + optional loss) connecting the given variables.
Returns a FactorKey that can be used to remove the block later.
pub fn remove_residual_block( &mut self, block_id: FactorKey, ) -> Option<ResidualBlock>
pub fn fix_variable(&mut self, var_key: VarKey, idx: usize)
pub fn unfix_variable(&mut self, var_key: VarKey)
pub fn set_variable_bounds( &mut self, var_key: VarKey, idx: usize, lower_bound: f64, upper_bound: f64, )
pub fn remove_variable_bounds(&mut self, var_key: VarKey)
Sourcepub fn apply_constraints_to_variables(
&self,
variables: &mut SlotMap<VarKey, Box<dyn ManifoldVariable>>,
)
pub fn apply_constraints_to_variables( &self, variables: &mut SlotMap<VarKey, Box<dyn ManifoldVariable>>, )
Apply fixed indices and bounds to a mutable clone of the variable map.
Optimizers call this after copying problem.variables to initialize working state.
pub fn num_residual_blocks(&self) -> usize
Sourcepub fn compute_residual_sparse(
&self,
variables: &SlotMap<VarKey, Box<dyn ManifoldVariable>>,
) -> CoreResult<Mat<f64>>
pub fn compute_residual_sparse( &self, variables: &SlotMap<VarKey, Box<dyn ManifoldVariable>>, ) -> CoreResult<Mat<f64>>
Compute only the residual vector (no Jacobian) for the given variable values.
Sourcepub fn compute_residual_and_jacobian_sparse(
&self,
variables: &SlotMap<VarKey, Box<dyn ManifoldVariable>>,
variable_index_map: &SecondaryMap<VarKey, usize>,
symbolic_structure: &SymbolicStructure,
) -> CoreResult<(Mat<f64>, SparseColMat<usize, f64>)>
pub fn compute_residual_and_jacobian_sparse( &self, variables: &SlotMap<VarKey, Box<dyn ManifoldVariable>>, variable_index_map: &SecondaryMap<VarKey, usize>, symbolic_structure: &SymbolicStructure, ) -> CoreResult<(Mat<f64>, SparseColMat<usize, f64>)>
Compute residuals and sparse Jacobian.
Sourcepub fn compute_residual_and_jacobian_dense(
&self,
variables: &SlotMap<VarKey, Box<dyn ManifoldVariable>>,
variable_index_map: &SecondaryMap<VarKey, usize>,
total_dof: usize,
) -> CoreResult<(Mat<f64>, Mat<f64>)>
pub fn compute_residual_and_jacobian_dense( &self, variables: &SlotMap<VarKey, Box<dyn ManifoldVariable>>, variable_index_map: &SecondaryMap<VarKey, usize>, total_dof: usize, ) -> CoreResult<(Mat<f64>, Mat<f64>)>
Compute residuals and dense Jacobian.
pub fn log_residual_to_file( &self, residual: &DVector<f64>, filename: &str, ) -> Result<(), Error>
pub fn log_sparse_jacobian_to_file( &self, jacobian: &SparseColMat<usize, f64>, filename: &str, ) -> Result<(), Error>
pub fn log_variables_to_file( &self, variables: &SlotMap<VarKey, Box<dyn ManifoldVariable>>, filename: &str, ) -> Result<(), Error>
pub fn compute_and_set_covariances( &self, linear_solver: &mut Box<dyn LinearSolver<SparseMode>>, variables: &mut SlotMap<VarKey, Box<dyn ManifoldVariable>>, variable_index_map: &SecondaryMap<VarKey, usize>, ) -> Option<SecondaryMap<VarKey, Mat<f64>>>
pub fn compute_and_set_covariances_generic<M: LinearizationMode>( &self, linear_solver: &mut dyn LinearSolver<M>, variables: &mut SlotMap<VarKey, Box<dyn ManifoldVariable>>, variable_index_map: &SecondaryMap<VarKey, usize>, ) -> Option<SecondaryMap<VarKey, Mat<f64>>>