Module sparse

Module sparse 

Sparse Jacobian assembly using symbolic sparsity patterns.

Structs

SymbolicStructure
Symbolic structure for sparse matrix operations.

Functions

assemble_sparse
Assemble residuals and sparse Jacobian from the current variable values.
build_symbolic_structure
Build the symbolic sparsity structure for the Jacobian matrix.