pub struct VisualizationConfig {Show 20 fields
pub show_cameras: bool,
pub show_landmarks: bool,
pub show_se2_poses: bool,
pub show_plots: bool,
pub show_matrices: bool,
pub camera_fov: f32,
pub camera_aspect_ratio: f32,
pub camera_frustum_scale: f32,
pub landmark_point_size: f32,
pub initial_landmark_color: [u8; 3],
pub optimized_landmark_color: [u8; 3],
pub se2_pose_radius: f32,
pub se2_box_half_size: f32,
pub initial_se2_color: [u8; 3],
pub optimized_se2_color: [u8; 3],
pub hessian_downsample_size: usize,
pub gradient_bar_width: usize,
pub graph_scale: f32,
pub invert_camera_poses: bool,
pub visualization_mode: VisualizationMode,
}Expand description
Configuration for visualization options in RerunObserver.
This struct controls what elements are visualized and their appearance. Use the builder pattern to customize settings.
Examples
use apex_solver::observers::VisualizationConfig;
// Default: show everything
let config = VisualizationConfig::new();
// Cameras only with larger frustums
let config = VisualizationConfig::cameras_only()
.with_camera_fov(0.8)
.with_camera_frustum_scale(2.0);
// Landmarks only with larger points
let config = VisualizationConfig::landmarks_only()
.with_landmark_point_size(0.05);
// Bundle adjustment preset
let config = VisualizationConfig::for_bundle_adjustment();Fields
show_cameras: boolShow camera poses (SE3 variables) as frustums
show_landmarks: boolShow 3D landmarks (Rn with dim=3) as point cloud
show_se2_poses: boolShow SE2 poses (for 2D SLAM)
show_plots: boolShow time series plots (cost, gradient, damping, etc.)
show_matrices: boolShow matrix visualizations (Hessian, gradient)
camera_fov: f32Camera frustum field of view in radians (default: 0.5)
camera_aspect_ratio: f32Camera frustum aspect ratio (default: 1.0)
camera_frustum_scale: f32Scale factor for camera frustum size (default: 1.0)
landmark_point_size: f32Radius of 3D landmark points (default: 0.02)
initial_landmark_color: [u8; 3]Color for initial landmarks RGB (default: blue [100, 150, 255])
optimized_landmark_color: [u8; 3]Color for optimized landmarks RGB (default: gold [255, 200, 50])
se2_pose_radius: f32Radius for SE2 pose markers (default: 0.5)
se2_box_half_size: f32Half-size for SE2 pose box markers (default: 0.3)
initial_se2_color: [u8; 3]Color for initial SE2 poses RGB (default: blue [100, 150, 255])
optimized_se2_color: [u8; 3]Color for optimized SE2 poses RGB (default: green [50, 200, 100])
hessian_downsample_size: usizeTarget size for Hessian downsampling (default: 100)
gradient_bar_width: usizeTarget width for gradient visualization (default: 100)
graph_scale: f32Graph scale factor for pose graph visualization
invert_camera_poses: boolInvert camera poses for display (T_wc -> T_cw for BA)
visualization_mode: VisualizationModeVisualization mode: iterative or initial-and-final only
Implementations
Sourceimpl VisualizationConfig
impl VisualizationConfig
Sourcepub fn with_show_cameras(self, show: bool) -> Self
pub fn with_show_cameras(self, show: bool) -> Self
Set whether to show camera poses (SE3 frustums).
Sourcepub fn with_show_landmarks(self, show: bool) -> Self
pub fn with_show_landmarks(self, show: bool) -> Self
Set whether to show 3D landmarks.
Sourcepub fn with_show_se2_poses(self, show: bool) -> Self
pub fn with_show_se2_poses(self, show: bool) -> Self
Set whether to show SE2 poses.
Sourcepub fn with_show_plots(self, show: bool) -> Self
pub fn with_show_plots(self, show: bool) -> Self
Set whether to show time series plots.
Sourcepub fn with_show_matrices(self, show: bool) -> Self
pub fn with_show_matrices(self, show: bool) -> Self
Set whether to show matrix visualizations.
Sourcepub fn with_camera_fov(self, fov: f32) -> Self
pub fn with_camera_fov(self, fov: f32) -> Self
Set camera frustum field of view in radians.
Sourcepub fn with_camera_aspect_ratio(self, ratio: f32) -> Self
pub fn with_camera_aspect_ratio(self, ratio: f32) -> Self
Set camera frustum aspect ratio.
Sourcepub fn with_camera_frustum_scale(self, scale: f32) -> Self
pub fn with_camera_frustum_scale(self, scale: f32) -> Self
Set camera frustum scale factor.
Sourcepub fn with_landmark_point_size(self, size: f32) -> Self
pub fn with_landmark_point_size(self, size: f32) -> Self
Set 3D landmark point size/radius.
Sourcepub fn with_initial_landmark_color(self, rgb: [u8; 3]) -> Self
pub fn with_initial_landmark_color(self, rgb: [u8; 3]) -> Self
Set color for initial landmarks (RGB).
Sourcepub fn with_optimized_landmark_color(self, rgb: [u8; 3]) -> Self
pub fn with_optimized_landmark_color(self, rgb: [u8; 3]) -> Self
Set color for optimized landmarks (RGB).
Sourcepub fn with_se2_pose_radius(self, radius: f32) -> Self
pub fn with_se2_pose_radius(self, radius: f32) -> Self
Set SE2 pose marker radius.
Sourcepub fn with_se2_box_half_size(self, half_size: f32) -> Self
pub fn with_se2_box_half_size(self, half_size: f32) -> Self
Set SE2 pose box half-size.
Sourcepub fn with_initial_se2_color(self, rgb: [u8; 3]) -> Self
pub fn with_initial_se2_color(self, rgb: [u8; 3]) -> Self
Set color for initial SE2 poses (RGB).
Sourcepub fn with_optimized_se2_color(self, rgb: [u8; 3]) -> Self
pub fn with_optimized_se2_color(self, rgb: [u8; 3]) -> Self
Set color for optimized SE2 poses (RGB).
Sourcepub fn with_hessian_downsample_size(self, size: usize) -> Self
pub fn with_hessian_downsample_size(self, size: usize) -> Self
Set target size for Hessian downsampling.
Sourcepub fn with_gradient_bar_width(self, width: usize) -> Self
pub fn with_gradient_bar_width(self, width: usize) -> Self
Set target width for gradient visualization.
Sourcepub fn with_graph_scale(self, scale: f32) -> Self
pub fn with_graph_scale(self, scale: f32) -> Self
Set graph scale factor.
Sourcepub fn with_invert_camera_poses(self, invert: bool) -> Self
pub fn with_invert_camera_poses(self, invert: bool) -> Self
Set whether to invert camera poses (T_wc -> T_cw).
Sourcepub fn with_visualization_mode(self, mode: VisualizationMode) -> Self
pub fn with_visualization_mode(self, mode: VisualizationMode) -> Self
Sourcepub fn cameras_only() -> Self
pub fn cameras_only() -> Self
Create a configuration that shows only camera poses (no landmarks).
Useful for pose graph visualization or when landmarks are too dense.
Sourcepub fn landmarks_only() -> Self
pub fn landmarks_only() -> Self
Create a configuration that shows only 3D landmarks (no cameras).
Useful for structure-from-motion point cloud visualization.
Sourcepub fn for_bundle_adjustment() -> Self
pub fn for_bundle_adjustment() -> Self
Create a configuration optimized for bundle adjustment.
- Inverts camera poses (T_wc -> T_cw for correct display)
- Disables SE2 poses (not used in BA)
Sourcepub fn for_pose_graph() -> Self
pub fn for_pose_graph() -> Self
Create a configuration optimized for pose graph optimization.
- No camera pose inversion (poses are already T_cw)
- Disables landmarks (pose graphs don’t have 3D points)