pub struct SE3 { /* private fields */ }Expand description
SE(3) group element representing rigid body transformations in 3D.
Represented as a combination of SO(3) rotation and Vector3 translation.
Implementations
Sourceimpl SE3
impl SE3
Sourcepub const DIM: usize = 3
pub const DIM: usize = 3
Space dimension - dimension of the ambient space that the group acts on
Sourcepub fn identity() -> SE3
pub fn identity() -> SE3
Get the identity element of the group.
Returns the neutral element e such that e ∘ g = g ∘ e = g for any group element g.
Sourcepub fn jacobian_identity() -> Matrix<f64, Const<6>, Const<6>, ArrayStorage<f64, 6, 6>>
pub fn jacobian_identity() -> Matrix<f64, Const<6>, Const<6>, ArrayStorage<f64, 6, 6>>
Get the identity matrix for Jacobians.
Returns the identity matrix in the appropriate dimension for Jacobian computations.
Sourcepub fn new(
translation: Matrix<f64, Const<3>, Const<1>, ArrayStorage<f64, 3, 1>>,
rotation: Unit<Quaternion<f64>>,
) -> SE3
pub fn new( translation: Matrix<f64, Const<3>, Const<1>, ArrayStorage<f64, 3, 1>>, rotation: Unit<Quaternion<f64>>, ) -> SE3
Create a new SE3 element from translation and rotation.
Arguments
translation- Translation vector [x, y, z]rotation- Unit quaternion representing rotation
Sourcepub fn from_translation_quaternion(
translation: Matrix<f64, Const<3>, Const<1>, ArrayStorage<f64, 3, 1>>,
quaternion: Quaternion<f64>,
) -> SE3
pub fn from_translation_quaternion( translation: Matrix<f64, Const<3>, Const<1>, ArrayStorage<f64, 3, 1>>, quaternion: Quaternion<f64>, ) -> SE3
Create SE3 from translation components and Euler angles.
Sourcepub fn from_translation_euler(
x: f64,
y: f64,
z: f64,
roll: f64,
pitch: f64,
yaw: f64,
) -> SE3
pub fn from_translation_euler( x: f64, y: f64, z: f64, roll: f64, pitch: f64, yaw: f64, ) -> SE3
Create SE3 from translation components and Euler angles.
Sourcepub fn from_isometry(isometry: Isometry<f64, Unit<Quaternion<f64>>, 3>) -> SE3
pub fn from_isometry(isometry: Isometry<f64, Unit<Quaternion<f64>>, 3>) -> SE3
Create SE3 directly from an Isometry3.
Sourcepub fn from_translation_so3(
translation: Matrix<f64, Const<3>, Const<1>, ArrayStorage<f64, 3, 1>>,
rotation: SO3,
) -> SE3
pub fn from_translation_so3( translation: Matrix<f64, Const<3>, Const<1>, ArrayStorage<f64, 3, 1>>, rotation: SO3, ) -> SE3
Create SE3 from SO3 and Vector3 components.
Sourcepub fn translation(
&self,
) -> Matrix<f64, Const<3>, Const<1>, ArrayStorage<f64, 3, 1>>
pub fn translation( &self, ) -> Matrix<f64, Const<3>, Const<1>, ArrayStorage<f64, 3, 1>>
Get the translation part as a Vector3.
Sourcepub fn rotation_so3(&self) -> SO3
pub fn rotation_so3(&self) -> SO3
Get the rotation part as SO3.
Sourcepub fn rotation_quaternion(&self) -> Unit<Quaternion<f64>>
pub fn rotation_quaternion(&self) -> Unit<Quaternion<f64>>
Get the rotation part as a UnitQuaternion.
Sourcepub fn isometry(&self) -> Isometry<f64, Unit<Quaternion<f64>>, 3>
pub fn isometry(&self) -> Isometry<f64, Unit<Quaternion<f64>>, 3>
Get as an Isometry3 (convenience method).