pub struct SO2 { /* private fields */ }Expand description
SO(2) group element representing rotations in 2D.
Stored as a single angle θ (radians). UnitComplex is derived on demand for math operations, keeping storage minimal and contiguous.
Implementations
Sourceimpl SO2
impl SO2
Sourcepub const DIM: usize = 2
pub const DIM: usize = 2
Space dimension - dimension of the ambient space that the group acts on
Sourcepub fn jacobian_identity() -> Matrix<f64, Const<1>, Const<1>, ArrayStorage<f64, 1, 1>>
pub fn jacobian_identity() -> Matrix<f64, Const<1>, Const<1>, ArrayStorage<f64, 1, 1>>
Get the identity matrix for Jacobians.
Sourcepub fn new(complex: Unit<Complex<f64>>) -> SO2
pub fn new(complex: Unit<Complex<f64>>) -> SO2
Create a new SO(2) element from a unit complex number.
Sourcepub fn from_angle(angle: f64) -> SO2
pub fn from_angle(angle: f64) -> SO2
Create SO(2) from an angle.
Sourcepub fn rotation_matrix(
&self,
) -> Matrix<f64, Const<2>, Const<2>, ArrayStorage<f64, 2, 2>>
pub fn rotation_matrix( &self, ) -> Matrix<f64, Const<2>, Const<2>, ArrayStorage<f64, 2, 2>>
Get the rotation matrix (2x2).